
# q-expansion of newform 4732.2.a.t, downloaded from the LMFDB on 13 January 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 4732
weight = 2
poly_data = [52, -136, -232, 40, 113, -2, -19, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0], 1], [[-108, 270, 266, -193, -88, 47, 6, -3], 4], [[52, -194, -137, 138, 45, -32, -3, 2], 2], [[114, -388, -309, 274, 103, -64, -7, 4], 4], [[-154, 492, 391, -384, -133, 94, 9, -6], 4], [[-202, 662, 571, -467, -191, 111, 13, -7], 4], [[70, -200, -181, 137, 59, -32, -4, 2], 1]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, -1, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0], [2, 1, 1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 1, -1, 0], [0, 0, -1, 0, 0, 1, -1, -1], [0, 1, -1, 0, 0, -1, 1, 0], [2, 1, -1, 0, -1, 0, -1, 0], [2, -1, 0, 1, -1, 0, -1, -1], [1, 1, 0, 0, 0, 1, 0, 1], [1, -2, -1, 0, 0, 0, 3, -1], [1, 0, -2, 2, 1, -1, 2, 0], [5, -1, 0, 0, 1, 1, 0, 0], [1, 0, 0, 0, 0, 0, 0, -2], [0, -1, 0, -1, 1, 0, -1, -1], [0, -2, 0, 0, -1, 0, 3, 1], [4, 1, 0, 1, -1, -2, 1, 0], [4, -2, 0, 0, 2, -2, 2, 2], [3, -2, -1, 0, 0, 0, 1, 1], [0, 1, -1, -2, 0, -1, 1, 0], [4, -1, 0, -1, 1, 0, -1, 1], [-4, 0, -1, 0, -2, 1, -1, 1], [-1, -1, -3, 0, -1, -2, 1, -1], [-2, -4, -1, 0, 1, 1, 2, -1], [0, 0, 0, 1, 3, -1, 0, -1], [-3, 1, -1, -1, -2, 3, -1, 0], [-1, -1, 0, 0, 3, 1, 2, 1], [1, 2, 0, -2, 0, 0, 0, -2], [-3, 3, 1, 0, -5, 0, -1, -2], [0, -2, -1, -1, -1, 2, -1, -1], [-4, -2, 1, -1, 2, 2, 1, 0], [-2, 3, -2, 1, 1, -1, -2, -1], [2, 0, -1, 3, 2, 4, -3, 0], [5, -3, 0, 0, 1, 3, 2, 1], [-2, -4, 1, 1, 0, 0, 2, 2], [-3, 2, 0, 3, -2, -1, -1, 1], [4, 1, -2, 1, -1, -2, -1, -1], [2, -2, 0, -1, 7, 1, 2, -1], [6, -2, 0, -1, 1, -1, 2, 0], [0, 0, 4, 0, 5, 2, -1, 1], [-3, 2, -2, 3, 0, 0, 4, 2], [3, 1, 2, 0, 0, 1, 2, -1], [9, 1, 1, -1, -2, 1, -1, -1], [4, 0, 2, 1, -1, -3, -2, 1], [2, 1, 3, 1, -5, 0, -1, 2], [5, 3, 3, -4, -1, 0, -3, -1], [16, 5, 2, -1, -5, -2, 1, 1], [0, 0, 2, -2, -2, 2, 0, 0], [-3, -5, -3, 1, 6, 5, 1, -2], [4, -1, 2, -1, -1, 0, 1, 2], [-6, 1, 2, -2, 1, -2, 4, 2], [-8, 2, 2, -2, 4, 0, 0, 0], [-4, -4, 1, -3, 0, -2, 0, -2], [2, 1, 5, -3, -3, 4, -3, 0], [-4, -2, -3, 1, -5, 0, 1, -3], [4, -1, 0, -3, 3, 2, -1, -1], [-3, -2, 2, -2, 0, -2, 2, -2], [3, -5, -4, 2, 2, -3, 4, 1], [0, -5, -1, -2, -2, 3, 1, 2], [5, 6, 1, 2, -2, 0, -3, 1], [8, 3, -1, 3, 1, 1, -2, 4], [-2, 3, 0, 1, -1, -3, 6, 3], [0, -2, -4, 2, 6, -4, 2, 0], [6, 6, 0, -2, -5, 4, -4, -2], [4, 1, -3, 4, 6, -4, 2, 0], [6, -3, 1, 0, 7, -2, 5, 0], [-4, -5, 1, 4, 0, 1, 3, 4], [5, -1, 2, 2, 3, -1, 0, 2], [5, -2, -2, 4, 0, 1, -2, 2], [4, -4, -5, 1, 3, 2, 7, 0], [6, 1, -1, -4, 4, -1, -1, 0], [4, 7, 1, -3, -6, 1, -3, 0], [-6, 3, 1, 0, 6, 2, 2, 0], [10, 5, 1, -1, 5, 3, 2, -2], [5, 0, 2, 1, 3, -7, -2, 0], [2, 4, 6, -2, -4, -2, -2, -2], [-20, -2, -3, 1, -2, 4, 1, -2], [-9, -2, -2, -2, 0, -1, -4, -2], [-12, 1, -1, -1, 5, 2, -3, 3], [3, 5, 4, -2, -8, -3, 0, 3], [-2, 2, -5, 1, 1, 0, -1, 2], [-10, 2, 6, 1, -4, -3, -1, 2], [6, -7, 4, -3, 1, 1, 4, 1], [12, 2, 2, 4, -4, -2, 2, 4], [4, 2, 2, 4, -6, -4, 4, 4], [3, 3, 2, -6, 2, 1, -4, -5], [-9, -4, -6, 0, -10, 1, 0, -2], [2, -1, 4, -3, -5, 4, -3, -2], [12, 3, 3, -3, -7, 0, -1, -1], [-5, -2, 3, 3, -2, 0, 2, 2], [-2, -2, -1, -1, -1, 6, -5, -2], [1, 7, 5, -2, -1, -4, -1, 4], [-5, 0, 1, -6, 3, -1, 0, -1], [-8, 7, 6, -2, 0, -4, -4, 0], [2, 3, -3, 4, -1, 3, -3, 3], [8, -2, 4, -4, 1, -2, -1, 1], [4, -6, -2, 0, 4, -6, 2, -2], [-6, -2, 3, -1, -10, -2, -1, 4], [10, 7, -1, -1, 1, 2, -1, 0], [-3, 3, -1, -5, 7, -3, 3, 1], [-8, -5, -3, 2, 6, 1, 7, -2], [2, 12, 6, 2, -4, 2, -6, 4], [-3, -1, -1, -7, 2, -1, 3, -2], [-18, 1, -3, -2, 3, -3, 1, 1], [1, 5, 5, -2, -17, 4, -5, 3], [-4, 5, 2, -4, -7, 4, -6, 2], [-3, -1, 1, 0, -9, 0, -1, 0], [-14, 4, -3, 2, -1, 1, -8, -1], [0, -2, -2, 3, 1, 3, -2, -3], [-1, -3, -3, 1, -3, 1, 3, -1], [-8, -4, 6, 2, 7, -2, 0, 2], [-15, -4, -4, -1, 4, 1, 3, -3], [-5, -5, -1, -3, 4, 3, 9, 1], [4, 5, 1, 3, 8, -3, 3, 0], [9, 11, 4, -2, -15, -7, 2, 2], [4, -2, 4, -2, 0, 6, -6, 2], [-1, 3, 3, -2, -7, 4, -3, 0], [4, 0, -4, 4, 0, 4, 0, -2], [1, 4, -7, 2, -10, 4, -7, -1], [-5, -2, -2, 0, -2, -2, 4, 2], [-4, 2, -1, 0, -4, 11, -5, -4], [25, -7, 2, -2, 3, -1, 4, 3], [-4, 6, 3, 0, 6, -3, -5, -1], [6, -8, 0, -4, 2, -2, 8, 0], [-6, -2, -3, -1, 6, -2, -1, -4], [-2, -7, -3, 7, 1, -2, 1, 1], [-12, -4, 0, -1, -5, 1, 2, 3], [-6, -1, -4, 0, 3, 4, 4, 4], [-8, 10, 2, -2, -6, -2, -4, -4], [0, -10, -5, 3, 5, -2, 1, -2], [-12, 5, 1, -5, 5, 0, -7, -2], [4, -2, 4, 0, 0, 4, 4, 6], [13, -7, 1, 2, -1, 6, -7, -1], [-3, 7, -4, -2, -3, -5, 0, -4], [3, 7, 8, -6, -1, -1, -2, 4], [5, -8, 4, -1, -6, 7, 1, 1], [-20, 8, 0, 2, 0, -4, -8, 0], [9, 0, -2, 0, 6, -4, 2, -2], [3, -2, 7, 1, 0, 6, -6, 0], [7, -1, 6, 0, 5, 3, 4, 5], [-18, 6, -6, 3, -11, 1, -4, 0], [7, 0, 5, -8, -5, -3, 0, 1], [6, -2, -1, 2, 11, 5, -4, -5], [20, -2, -3, 4, 4, 1, -1, -3], [-12, 7, 5, 0, 11, -3, 1, -1], [0, 6, 5, -5, -12, 4, -6, 0], [-2, -7, -5, 0, 0, 7, -1, 0], [15, 6, 0, -3, -6, -7, 5, 1], [-14, -4, 2, 4, 7, 4, -6, 4], [16, 6, -4, 1, 6, -5, 7, 2], [-2, 3, -3, -7, -1, -2, 9, -2], [6, -6, 4, 0, 6, 2, -4, 4], [-2, -5, -1, 0, 0, -1, 1, 8], [1, 7, -1, -3, -2, 3, 3, 4], [4, -4, 2, 0, 10, 0, 6, 6], [-4, 7, 3, -2, 7, 1, -9, 1], [-6, 8, 8, -5, 10, -5, -5, 0], [15, -1, 4, -4, 13, 1, 2, 0], [-6, 1, -1, 0, 2, 2, -10, -2], [16, -10, 0, 3, 11, -7, 6, 6], [4, -5, 0, 3, -3, 2, -1, -4], [6, 10, -2, 1, 5, -5, -6, -1], [-10, 0, 2, -6, 5, -2, 2, -2], [19, 1, 5, -2, 3, -2, 3, 3], [-11, -2, 6, 3, 0, 0, -12, 4], [-8, 10, 4, 1, -12, 5, -5, 2], [-12, 10, 7, 5, -11, 4, -7, 4], [6, -4, -8, 7, -4, 3, 1, 0], [-1, -4, 1, 6, 7, -5, 4, 5], [-4, -9, -8, 4, 3, -4, 14, 0], [9, -5, -3, -2, 5, 2, 3, 2], [-15, 7, -1, -3, -9, -7, 5, -3], [-4, 5, 2, 2, -10, 4, -14, 0], [-6, 2, -6, 3, -2, 1, -3, 2], [2, -6, -10, 8, 0, 4, 2, 0], [-9, 1, 3, -1, -1, -7, 1, 5], [18, 0, 1, -3, -11, 4, -9, -1], [2, -2, -5, -1, 13, 2, 5, -11], [-12, -1, -6, 1, -5, 2, -11, -8], [-2, 8, 5, -6, -10, -1, -3, -10], [-1, -10, 0, 0, 12, 2, 2, 2], [-10, -2, -3, 4, -12, -3, 1, 5], [1, -5, -1, -1, 0, -3, 11, 1], [-6, 0, 6, 1, 6, -1, 7, 6], [-2, -12, 0, -2, 4, 4, 12, 0], [1, 5, 1, -2, 1, -2, -3, -1], [-17, 1, -2, 2, -8, 5, 4, 1], [18, 0, -3, 0, -8, 5, 1, -1], [14, -6, -2, -5, 16, 5, 3, -2], [3, 10, 3, 4, 9, -3, 0, -3], [-1, -9, -1, 5, 0, 5, 7, 0], [4, 2, -1, -2, -2, -9, -1, -1], [-21, 4, 6, -5, 4, 4, 0, 0], [-6, 4, -8, -3, 3, -1, -4, -5], [-1, 5, -7, 5, 7, -3, -5, -7], [10, -1, -5, -1, -8, -1, 9, -6], [-9, 0, -1, -2, 10, 10, 1, -3], [-10, -8, -10, 5, 9, 3, -2, -1], [1, 3, -9, 1, -3, -1, 7, -3], [0, 10, 3, 8, -4, 9, -7, 8], [4, -3, 5, 4, 1, -3, 1, 7], [12, -2, -3, 2, 3, 3, 2, -5], [-23, -9, -6, 0, 5, 7, 2, 2], [-8, 8, -2, 3, -12, -5, -7, 8], [-23, 4, 4, -1, -4, -3, -9, 1], [28, -5, 5, -1, 5, -4, 5, -2], [1, 15, 9, -1, -13, -5, -7, 7], [-8, 2, 2, -4, -12, 6, -6, -6], [-22, -5, -5, -2, -11, 6, 7, 0], [-18, 10, 1, -3, -5, -2, -5, -1], [0, 4, 2, 1, -13, 3, -4, 10], [21, -11, -6, 0, 13, 1, 8, 0], [15, 3, 3, 2, -17, 2, -1, 3], [6, -1, 5, -4, -5, 5, -5, -1], [-10, 1, 1, 3, -11, 0, 1, 8], [-14, 2, 3, 1, -4, -2, 4, 8], [20, -2, -1, 3, 17, -2, -3, -6], [-5, 5, -5, 11, -10, -1, -1, 7], [-2, -3, -7, -2, 9, 0, 1, -4], [-13, -5, 2, 8, 3, -1, 0, 0], [3, 13, 4, 4, -6, -9, -4, 1], [0, 12, 7, -3, -1, -2, -9, 8], [-2, -16, -5, 4, 12, -5, 7, 0], [6, 3, -7, 4, 13, 8, -7, -2], [-18, 0, -2, -1, -8, 1, 3, 0], [-7, -1, 1, 2, -9, -4, -13, -2], [14, -2, 11, -7, -5, 10, -1, 1], [5, -5, -2, -2, 1, 1, 10, 1], [9, 2, -2, 3, 5, -5, 10, -4], [2, 2, 0, 3, 9, -1, 14, 7], [-7, 2, 5, 8, -1, 11, -4, 1], [1, 0, 2, -5, -13, 7, -16, 2], [-18, -7, -9, 8, 16, -1, 7, 0], [7, -7, 8, 2, -3, 9, 0, 2], [-5, 15, 5, 0, -15, -4, -9, 3], [2, 8, 4, -2, -11, 10, -10, -2], [14, 2, 2, -6, 10, -4, 6, 4], [-22, 9, 9, 1, -13, 8, -11, 1], [24, -1, 3, 0, 0, 8, -2, -6], [0, 7, -1, -1, -19, -6, 1, -1], [6, -2, 3, -5, 11, -4, 9, -3], [-6, 6, 0, 10, 3, -8, 4, 0], [-21, 14, -1, -4, -14, 8, -3, 1], [16, -11, -3, 2, -2, -7, 3, 6], [-3, -4, 4, 1, 4, -7, -7, 3], [6, 0, -1, 2, 10, 1, -1, 5], [21, 6, -2, 3, 2, -3, 5, 5], [-21, 5, -1, -4, 1, -4, -3, 0], [36, -2, 9, -3, 1, 6, 7, -4], [1, 13, 1, -6, -5, 2, -7, -11], [23, -7, 0, 4, -11, 3, -4, -3], [18, 0, 2, -1, -6, -3, 5, 0], [4, 2, -6, 3, -3, 1, 0, -9], [15, 5, 0, -4, -19, 3, -4, 3], [-17, -7, -7, 3, 4, 3, -7, -6], [-9, -1, 2, -4, -7, 5, 2, 8], [-2, 14, 6, 3, -5, 3, -8, 7], [-10, -1, 2, 2, -3, -2, -12, -2], [-2, -2, 2, 3, 5, -7, 4, 0], [-10, 14, 2, 3, 1, 1, 0, 0], [2, 1, 7, 2, -5, -3, -3, -1], [14, 8, 2, -9, 6, 1, 1, 0], [-17, 0, -11, 6, -2, 6, -7, -1], [10, 5, 3, 0, -12, -5, -1, 8], [21, -15, -8, -4, 17, -1, 14, 1], [22, -7, 6, 0, 3, -6, 14, 10], [-11, -3, -6, 2, -13, 3, 4, -5], [-3, -2, 2, 2, 2, 6, -16, 0], [-14, -6, 3, -3, 4, 12, -14, 0], [2, 2, -7, 5, 9, -10, 13, -2], [-3, 0, -1, -2, -4, 0, 9, 7], [18, -6, 2, 3, -1, 11, -8, -2], [-14, -4, 10, -6, 2, 8, -2, 2], [13, -4, 1, -9, 4, -8, 0, 0], [14, -13, 0, -1, 5, -2, 9, -4], [-13, -5, 4, -6, 18, 7, -10, -3], [-3, -3, 6, -8, 4, -3, 4, 1], [8, 4, -2, 1, 11, -3, 10, -1], [10, 6, 1, -7, 1, -4, 3, -3], [26, -16, -7, -3, 19, -4, 7, -8], [10, 1, 8, 0, -4, 6, -10, -2], [7, 4, -9, 8, -16, -6, -9, 1], [-7, 7, -10, -2, 13, -13, 4, 0], [-2, 6, 0, 0, 8, 8, -4, 0], [-16, 5, 3, 1, 6, 7, -13, 6], [19, 7, -3, -1, -11, 7, -5, 1], [-12, 6, 8, -4, 0, 2, -2, 4], [-14, -10, -3, 4, 29, -11, 14, -3], [-4, -12, -10, 3, -15, 1, 0, 2], [16, 6, 3, 1, -5, -8, -3, 5], [-11, -3, -8, 10, 14, -5, 4, -1], [12, -9, 3, 1, 3, 3, -6, 6], [20, 12, -2, -6, -2, 0, 6, -6], [-10, -4, 7, 1, 16, 0, -2, 2], [8, -8, -11, -4, 16, -5, 11, -10], [-4, -4, -7, 9, 4, 6, 4, -8], [8, -8, 9, -6, 8, -7, 5, 4], [5, -8, -13, 5, 10, 0, 2, -12], [-6, 8, 4, 4, -13, 8, 3, 9], [32, -8, 1, -1, -2, 0, 3, -6], [4, 10, 12, -2, -10, -2, -12, 4], [-4, 10, -8, 1, 1, -5, -10, -8], [-14, -10, 2, 3, -1, 11, -4, 0], [-2, 0, 0, 6, 9, 8, 8, -4], [12, -6, 8, 5, -11, -5, 10, -2], [-28, 12, 0, -3, -14, 9, -7, -6], [-8, 1, -4, -3, 9, -6, 5, 4], [-11, 4, 4, 7, 1, 11, -2, 2], [-12, -2, -2, -7, 5, 9, 0, -9], [15, -17, 2, 0, 3, -9, 4, -3], [25, -6, 6, -2, -4, 12, 4, 4], [7, 6, 10, -11, -10, 6, 0, 4], [18, -8, -3, -3, 19, -4, 11, 0], [-20, 8, -3, 3, 4, 4, 2, -6], [24, -13, -2, -11, 5, -6, 15, -1], [-21, -20, -8, 3, 14, 5, 15, -3], [-3, 3, 6, -6, -7, 5, -6, -8], [-15, -8, -6, 9, -3, -1, 10, 4], [4, -5, 5, -1, 13, 12, -5, 1], [-10, -4, -15, 9, -3, 4, 3, -2], [2, 0, -2, 5, -8, -11, 3, 4], [-11, 11, -7, -3, -10, 9, -3, -3], [14, -6, -2, 6, 8, 2, 2, 4], [2, 16, -5, -1, 4, -6, 0, 4], [-5, -7, 1, 1, 2, -9, 13, 5], [-11, 8, 1, 1, -12, 0, -2, 8], [-19, -24, -20, 3, 10, 4, 6, -6], [19, 4, -2, -3, -23, -13, -2, -8], [32, -6, 4, -8, -1, 2, 2, 0], [-12, -19, -9, -6, -5, 4, -1, 0], [-8, 8, 0, -2, -8, -2, -14, 0], [7, -11, -4, 0, 7, -5, 8, 0], [-4, 2, 7, -5, -19, 6, -15, 4], [26, -2, 2, 0, 4, 10, -16, -10], [-32, -14, -4, 4, -3, 4, 0, -2], [-8, 6, -4, -2, 14, -2, 4, -4], [18, -7, -8, 4, -15, -4, 0, 0], [12, -13, -11, 5, 13, 14, -3, -5], [6, 2, -1, 3, -11, -2, 3, 6], [-15, 0, 6, 3, 11, 9, -6, 8], [-2, 13, -4, 4, -9, 2, -10, 4], [12, -3, -3, 2, -4, -15, 7, -2], [14, -8, 4, 2, -2, -2, -6, -2], [0, 11, 3, 4, 6, 5, 5, -4], [-14, 6, 7, -10, 1, 1, -6, 7], [0, -2, 2, 0, -12, -4, -4, -4], [0, 3, 2, -3, -11, 2, -5, -11], [0, 2, -2, 3, 3, 1, -14, -5], [-31, -19, -8, -2, 9, 11, 0, -4], [-26, 2, 2, -6, 2, 6, -2, 6], [40, 2, 2, -6, -5, -10, 4, -2], [10, 1, 2, 5, -9, -1, -8, 11], [-25, -12, -4, 4, 14, -6, 0, 0], [-20, 2, 11, -3, -10, 2, -10, 6], [8, 0, 11, 4, -2, -5, -7, -3], [-16, -2, 4, -6, -14, 4, -18, -2], [-14, 5, 1, 0, -9, -4, -5, 8], [30, 8, 4, 2, -2, 6, 6, -2], [17, 1, 5, 3, -13, 9, -9, -3], [-36, 16, 6, -4, -7, 2, -1, 7], [-26, -8, -6, 2, 6, -4, 2, 2], [10, -3, -4, 9, 3, 2, 7, 12], [-6, 20, -12, 4, -14, -6, 0, 4], [-26, -14, 6, 1, -5, -5, -8, 4], [-6, -10, -12, -8, 8, 2, 4, -4], [-24, -7, 1, 0, 10, 12, 10, 6], [10, -9, -1, 1, -6, -5, 3, 0], [2, 2, -6, -2, -22, 8, -6, 2], [0, -5, -11, 9, 15, 6, 7, -7], [21, 15, 5, -7, -4, -7, -7, 1], [12, -3, 5, -7, -20, -9, 5, 2], [12, -3, 7, -10, -16, 3, 3, 0], [-4, -13, -1, 0, 5, 0, 5, 4], [-9, -7, 2, -4, 3, 5, -10, -2], [-34, -13, 7, -4, 0, -1, 1, -4], [-23, 11, -5, 4, 1, -8, -3, -1], [0, 12, 14, -9, -2, 3, -13, -6], [16, -8, 0, 1, 0, 1, 7, -2], [17, -11, -11, 2, 13, 0, 11, 1], [36, 10, 6, -2, -7, -6, -12, 0], [-14, -9, -4, -9, -3, 14, 9, 2], [23, 21, -8, 6, 5, -3, 0, 7], [-18, 7, 15, -5, -7, -9, -10, -2], [30, 12, 0, 2, 10, 4, -16, -6], [0, 9, 4, 5, -11, -2, 5, -2], [-26, 2, -4, 3, 3, -3, 2, 1], [10, -7, -8, 1, 5, 2, 3, -4], [-6, -3, -11, -8, 8, -3, -3, -12], [-4, 6, 15, -9, 8, 0, -1, 4], [12, -9, 3, -2, -19, 11, -3, 3], [3, 2, -5, -2, 9, 11, -4, -3], [18, -3, -1, 3, -23, -4, -13, -9], [3, -8, 3, -4, -5, -5, 2, -5], [-24, -6, 6, 4, 4, 10, -2, 0], [-24, 17, -1, -1, -17, 21, -10, -4], [6, 0, -10, 4, 0, -2, 6, 0], [-3, 6, -4, -4, 15, -9, 4, 6], [0, -20, -3, 7, 0, 12, 3, -6], [47, -5, 2, 4, 9, -1, -4, -6], [9, -3, -3, 2, -21, -4, -17, -2], [2, -10, 6, -2, 0, 10, -18, 8], [-4, -19, -12, -4, 21, 12, 6, 2], [-2, -9, 4, 14, -5, 4, 2, 10], [0, 5, -5, 7, -3, -2, -7, 5], [-8, -10, -10, -8, 14, -8, 24, -6], [13, 1, 0, -6, -2, -7, -10, -15], [5, 2, 4, -3, 2, 5, -3, -3], [-10, 12, 8, -2, 16, 6, -10, -2], [16, 6, -7, 9, 2, -12, -4, 2], [19, -2, -2, 1, -15, 7, -6, -4], [-20, -4, 6, -5, -5, -13, -8, 6], [-4, -8, -4, 4, -10, 2, 0, -6], [31, 12, 2, -8, -8, 0, -8, -6], [12, 0, 6, -2, -5, -8, -1, 1], [2, 12, 6, -6, -10, 4, 0, 10], [-10, 5, 12, 8, -2, 10, -4, 8], [-19, -13, -8, 6, 13, -13, 16, 8], [-16, 3, -1, -3, 5, -4, 3, 13], [21, 6, 2, 10, 4, 0, -4, 8], [16, 15, 9, -2, 5, 3, 1, -7], [15, -7, -2, 12, -15, 9, -6, 5], [16, -9, 1, 1, -1, -10, 23, 7], [-12, -4, -4, 12, -4, -10, 22, 8], [32, -1, -2, 0, 3, -2, 4, 2], [4, -1, -13, 2, -4, 3, -3, 2], [-16, -14, 1, 1, -6, 12, -3, -2], [-15, 7, 4, -8, -19, -3, 0, 2], [8, 5, -5, 7, -11, 2, 1, -3]]
